Working with Command Line Tools
===============================

Most users are familiar with `ansible` and `ansible-playbook`, but those are not the only utilities Ansible provides.
Below is a complete list of Ansible utilities. Each page contains a description of the utility and a listing of supported parameters.	

.. toctree:: 
   :maxdepth: 1

   ../cli/ansible.rst
   ../cli/ansible-config.rst
   ../cli/ansible-console.rst
   ../cli/ansible-doc.rst
   ../cli/ansible-galaxy.rst
   ../cli/ansible-inventory.rst
   ../cli/ansible-playbook.rst
   ../cli/ansible-pull.rst
   ../cli/ansible-vault.rst
   